@@ -23,5 +23,5 @@ def create_threadpool_executed_func(original_func):
         else:
             raise result[0], result[1], result[2]
     new_func.__name__ = original_func.__name__
-    new_func.__doc__ = "(gevent-friendly) " + original_func.__doc__
+    new_func.__doc__ = "(gevent-friendly)" + (" " + original_func.__doc__ if original_func.__doc__ is not None else "")
     return new_func
